==> toycars-0.3.0.tar.gz: toycars-0.3.0/src/WheelSprite.cpp <==
/*
	Copyright (C) 2005 by Ruben Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Zilibowitz on 31/12/04.
 */

#include "WheelSprite.h"
#include "ToyCar.h"
#include "SDL.h"
#include "SDL_image.h"
#include "ScException.h"
#include "GameConstants.h"

// Sprite Constants

const char kWheelSpriteFile[] = "images/wheel.png";
const int kWheelFrameWidth = 21;
const int kWheelFrameHeight = 21;
const ScRect kWheelBounds = {0, 0, kWheelFrameWidth, kWheelFrameHeight};

///--------------------------------------------------------------------------------------
//  WheelSprite::WheelSprite
///--------------------------------------------------------------------------------------

WheelSprite::WheelSprite(const ToyCar* inParentCarP, const char *spritefilename, short framewidth, short frameheight, const Wheel* inWheelP, double inBaseAngle)
    : ScSprite(framewidth, frameheight), parentCarP(inParentCarP), wheelP(inWheelP), baseAngle(inBaseAngle)
{
	SDL_Surface* imgSurface;
	ScPixelData pixelData;
	
	// this is a master sprite
	isMaster = true;
    
	// create image surface
	imgSurface = IMG_Load(spritefilename);
	if(!imgSurface)
	{
		ScThrowErr("Could not load image file");
	}
	
	// setup the pixel data struct
	pixelData.pitch = imgSurface->pitch;
	pixelData.bytes_pp = imgSurface->format->BytesPerPixel;
	pixelData.internalformat = GL_RGBA;
	pixelData.width = imgSurface->w;
	pixelData.height = imgSurface->h;
	pixelData.format = GL_RGBA;
	pixelData.type = GL_UNSIGNED_BYTE;
	pixelData.pixels = (const char*)(imgSurface->pixels);
    
	// load the sprite frames
	load(framewidth, frameheight, 0, pixelData);
	
	// free the image surface
	SDL_FreeSurface(imgSurface);
}

///--------------------------------------------------------------------------------------
//  WheelSprite::WheelSprite
///--------------------------------------------------------------------------------------

WheelSprite::WheelSprite(const ToyCar* inParentCarP, const Wheel* inWheelP, double inBaseAngle)
    : ScSprite(kWheelBounds), parentCarP(inParentCarP), wheelP(inWheelP), baseAngle(inBaseAngle)
{
	SDL_Surface* imgSurface;
	ScPixelData pixelData;
	
	// this is a master sprite
	isMaster = true;

	// create image surface
	imgSurface = IMG_Load(kWheelSpriteFile);
	if(!imgSurface)
	{
		ScThrowErr("Could not load image file");
	}
	
	// setup the pixel data struct
	pixelData.pitch = imgSurface->pitch;
	pixelData.bytes_pp = imgSurface->format->BytesPerPixel;
	pixelData.internalformat = GL_RGBA;
	pixelData.width = imgSurface->w;
	pixelData.height = imgSurface->h;
	pixelData.format = GL_RGBA;
	pixelData.type = GL_UNSIGNED_BYTE;
	pixelData.pixels = (const char*)(imgSurface->pixels);
		
	// load the sprite frames
	load(kWheelFrameWidth, kWheelFrameHeight, 0, pixelData);
	
	// free the image surface
	SDL_FreeSurface(imgSurface);
}

///--------------------------------------------------------------------------------------
//  WheelSprite::WheelSprite
//  copy constructor
///--------------------------------------------------------------------------------------

WheelSprite::WheelSprite(const WheelSprite& copyWheel, const ToyCar* inParentCarP, const Wheel* inWheelP, double inBaseAngle)
	: ScSprite(copyWheel), parentCarP(inParentCarP), wheelP(inWheelP), baseAngle(inBaseAngle)
{
}

///--------------------------------------------------------------------------------------
//  WheelSprite::draw
///--------------------------------------------------------------------------------------

void WheelSprite::process(ScFloat dt)
{
    location_wc = parentCarP->getNorm().fromLocal(wheelP->getHinge_vc()) + parentCarP->getLocation_wc();
	orientation_wc = parentCarP->getOrientation_wc() + wheelP->getOrientation_vc() + baseAngle;
	
    centreAt(location_wc.x * kScale, location_wc.y * kScale);
	
    curFrame = iround(orientation_wc * kInvTwoPi * numFrames);
	while (curFrame < 0)	curFrame += numFrames;
	while (curFrame >= numFrames)	curFrame -= numFrames;
}

==> toycars-0.3.3.tar.gz: toycars-0.3.3/src/WheelSprite.cpp <==
/*
	Copyright (C) 2005 by Ruben Henner Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Henner Zilibowitz on 31/12/04.
 */

#include "WheelSprite.h"
#include "ToyCar.h"
#include "SDL.h"
#include "SDL_image.h"
#include "ScException.h"
#include "GameConstants.h"

// Sprite Constants

const char kWheelSpriteFile[] = "images/wheel.png";
const int kWheelFrameWidth = 21;
const int kWheelFrameHeight = 21;
const ScRect kWheelBounds = {0, 0, kWheelFrameWidth, kWheelFrameHeight};

///--------------------------------------------------------------------------------------
//  WheelSprite::WheelSprite
///--------------------------------------------------------------------------------------

WheelSprite::WheelSprite(const ToyCar* inParentCarP, const char *spritefilename, short framewidth, short frameheight, const Wheel* inWheelP, double inBaseAngle)
    : ScSprite(framewidth, frameheight), parentCarP(inParentCarP), wheelP(inWheelP), baseAngle(inBaseAngle)
{
	SDL_Surface* imgSurface;
	ScPixelData pixelData;
	
	// this is a master sprite
	isMaster = true;
    
	// create image surface
	imgSurface = IMG_Load(spritefilename);
	if(!imgSurface)
	{
		ScThrowErr("Could not load image file");
	}
	
	// setup the pixel data struct
	pixelData.pitch = imgSurface->pitch;
	pixelData.bytes_pp = imgSurface->format->BytesPerPixel;
	pixelData.internalformat = GL_RGBA;
	pixelData.width = imgSurface->w;
	pixelData.height = imgSurface->h;
	pixelData.format = GL_RGBA;
	pixelData.type = GL_UNSIGNED_BYTE;
	pixelData.pixels = (const char*)(imgSurface->pixels);
    
	// load the sprite frames
	load(framewidth, frameheight, 0, pixelData);
	
	// free the image surface
	SDL_FreeSurface(imgSurface);
}

///--------------------------------------------------------------------------------------
//  WheelSprite::WheelSprite
///--------------------------------------------------------------------------------------

WheelSprite::WheelSprite(const ToyCar* inParentCarP, const Wheel* inWheelP, double inBaseAngle)
    : ScSprite(kWheelBounds), parentCarP(inParentCarP), wheelP(inWheelP), baseAngle(inBaseAngle)
{
	SDL_Surface* imgSurface;
	ScPixelData pixelData;
	
	// this is a master sprite
	isMaster = true;

	// create image surface
	imgSurface = IMG_Load(kWheelSpriteFile);
	if(!imgSurface)
	{
		ScThrowErr("Could not load image file");
	}
	
	// setup the pixel data struct
	pixelData.pitch = imgSurface->pitch;
	pixelData.bytes_pp = imgSurface->format->BytesPerPixel;
	pixelData.internalformat = GL_RGBA;
	pixelData.width = imgSurface->w;
	pixelData.height = imgSurface->h;
	pixelData.format = GL_RGBA;
	pixelData.type = GL_UNSIGNED_BYTE;
	pixelData.pixels = (const char*)(imgSurface->pixels);
		
	// load the sprite frames
	load(kWheelFrameWidth, kWheelFrameHeight, 0, pixelData);
	
	// free the image surface
	SDL_FreeSurface(imgSurface);
}

///--------------------------------------------------------------------------------------
//  WheelSprite::WheelSprite
//  copy constructor
///--------------------------------------------------------------------------------------

WheelSprite::WheelSprite(const WheelSprite& copyWheel, const ToyCar* inParentCarP, const Wheel* inWheelP, double inBaseAngle)
	: ScSprite(copyWheel), parentCarP(inParentCarP), wheelP(inWheelP), baseAngle(inBaseAngle)
{
}

///--------------------------------------------------------------------------------------
//  WheelSprite::draw
///--------------------------------------------------------------------------------------

void WheelSprite::process(ScFloat dt)
{
    location_wc = parentCarP->getNorm().fromLocal(wheelP->getHinge_vc()) + parentCarP->getLocation_wc();
	orientation_wc = parentCarP->getOrientation_wc() + wheelP->getOrientation_vc() + baseAngle;
	
    centreAt(location_wc.x * kScale, location_wc.y * kScale);
	
    curFrame = iround(orientation_wc * kInvTwoPi * numFrames);
	while (curFrame < 0)	curFrame += numFrames;
	while (curFrame >= numFrames)	curFrame -= numFrames;
}
